# {{ sitename }} website

Code for site at: https://{{ domain }}


## Getting started

Make sure a recent version of Python is installed on your system.
Open this directory in a command prompt, then:

1. Create a virtual environment (for Windows, use python instead of python3):
   ```
   python3 -m venv env-yourprojectname
   ```

   ```
2. Install the software:
   ```
   pip install -r requirements.txt
   ```

3. Run the development server:
   ```
   python manage.py runserver
   ```
   or
   ```
   ./manage.py runserver
   ```

4. Go to http://localhost:8000/ in your browser, or http://localhost:8000/backend/
   to log in and get to work!

---

Made with ♥ using [Wagtail](https://wagtail.io/) +
[CJKCms is based on a fork of CodeRed Extensions](https://www.coderedcorp.com/cms/)
